package cn.com.qmth.stmms.biz.exam.dao;

import cn.com.qmth.stmms.biz.exam.model.Exam;
import cn.com.qmth.stmms.common.enums.ExamStatus;
import cn.com.qmth.stmms.common.enums.ExamType;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.data.jpa.repository.JpaSpecificationExecutor;
import org.springframework.data.jpa.repository.Modifying;
import org.springframework.data.jpa.repository.Query;
import org.springframework.data.repository.PagingAndSortingRepository;

import java.util.Date;
import java.util.List;

public interface ExamDao extends PagingAndSortingRepository<Exam, Integer>, JpaSpecificationExecutor<Exam> {

    public Page<Exam> findAll(Pageable pageable);

    List<Exam> findByStatus(ExamStatus status);

    @Query("select e from Exam e where e.creatorId=?1 and e.status=?2 order by e.examTime desc")
    public List<Exam> findByCreatorAndStatus(Integer id, ExamStatus status);

    @Modifying
    @Query("update Exam e set e.status=?2 where e.id=?1")
    public void updateStatus(Integer examId, ExamStatus status);

    @Modifying
    @Query("update Exam e set e.sliceConfig=?2 where e.id=?1")
    public void updateSliceConfig(Integer examId, String configString);

    List<Exam> findBySchoolIdAndTypeAndStatusOrderByIdDesc(Integer schoolId, ExamType type, ExamStatus status);

    List<Exam> findBySchoolIdAndStatusOrderByIdDesc(Integer schoolId, ExamStatus status);

    @Modifying
    @Query("update Exam e set e.process=?2 where e.id=?1")
    public void updateProcess(Integer id, Double process);

    public Exam findFirstBySchoolIdAndCode(Integer schoolId, String code);

    @Query(value = "select * from eb_exam e where e.id in (select m.exam_id from eb_marker m where m.user_id=?1) and e.create_time >?2 "
            + "order by e.id", nativeQuery = true)
    public List<Exam> findByUserId(Integer id, Date time);
}
